@@ -1,6 +1,6 @@
 __all__ = ('LoanPoint', 'LoanObjectPoint', 'ClosedLoanPoint', 'ClosedLoanObjectPoint', 'LoanPaymentPoint',
            'ExportPoint', 'PartialLoanPaymentPoint', 'ExtendLoanPoint', 'RestructureLoanPoint', 'ValidateLoanPoint',
-           'PublicPaymentPoint', 'CallBackPaymentPoint',
+           'PublicPaymentPoint',
            )
 
 from typing import OrderedDict, Union
